@@ -16,6 +16,10 @@ try:
 except ImportError:
     from unittest import TestCase
 
+try:
+    RecursionError
+except NameError:
+    RecursionError = RuntimeError
 
 from chameleon.utils import byte_string
 from chameleon.exc import RenderError
@@ -302,6 +306,17 @@ class ZopePageTemplatesTest(RenderTestCase):
 
         self.from_string(body)
 
+    def test_recursion_error(self):
+        template = self.from_string(
+            '<div metal:define-macro="main" '
+            'metal:use-macro="template.macros.main" />'
+        )
+        self.assertRaises(RecursionError, template)
+        try:
+            template()
+        except RecursionError as exc:
+            self.assertFalse(isinstance(exc, RenderError))
+
     def test_unicode_decode_error(self):
         template = self.from_file(
             os.path.join(self.root, 'inputs', 'greeting.pt')
@@ -393,8 +408,8 @@ class ZopePageTemplatesTest(RenderTestCase):
             on_error_handler=handler
         )
         rendered = template()
-        self.assertEquals(len(exc), 1)
-        self.assertEquals(exc[0].__class__.__name__, "NameError")
+        self.assertEqual(len(exc), 1)
+        self.assertEqual(exc[0].__class__.__name__, "NameError")
 
     def test_object_substitution_coerce_to_str(self):
         template = self.from_string('${test}', translate=None)
